@@ -1,4 +1,4 @@
-from biolib.typing_utils import TypedDict, Optional, Literal, List
+from biolib.typing_utils import List, Literal, Optional, TypedDict
 
 JobState = Literal['in_progress', 'completed', 'failed', 'cancelled']
 
@@ -20,12 +20,18 @@ class CloudJobStartedDict(_BaseCloudJobDict):
     compute_node_url: str
 
 
+class Result(TypedDict):
+    name: str
+
+
 class JobDict(TypedDict):
     app_uri: str
     auth_token: str
     created_at: str
     ended_at: Optional[str]
+    requested_machine: str
     runtime_seconds: int
+    main_result: Result
     started_at: str
     state: JobState
     uuid: str
