@@ -10,7 +10,7 @@ from biolib.biolib_errors import BioLibError
 from biolib.biolib_logging import logger_no_user_data
 from biolib.typing_utils import Optional, Generic, TypeVar
 
-StateType = TypeVar('StateType')
+StateType = TypeVar('StateType')  # pylint: disable=invalid-name
 
 
 class CacheStateError(BioLibError):
@@ -37,7 +37,7 @@ class CacheState(abc.ABC, Generic[StateType]):
     def _state_lock_path(self) -> str:
         return f'{self._state_path}.lock'
 
-    def __init__(self):
+    def __init__(self) -> None:
         self._state: Optional[StateType] = None
 
     def __enter__(self) -> StateType:
